# Copyright 2021 Bedford Freeman & Worth Pub Grp LLC DBA Macmillan Learning.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# pipe for internal use ----------------------------------------

#' @importFrom magrittr %>%
magrittr::`%>%`

#' @importFrom rlang .data
rlang::.data

#' @importFrom rlang %||%
rlang::`%||%`

#' @importFrom fastmatch %fin%
fastmatch::`%fin%`

#' @importFrom morphemepiece.data morphemepiece_vocab
#' @export
morphemepiece.data::morphemepiece_vocab

#' @importFrom morphemepiece.data morphemepiece_lookup
#' @export
morphemepiece.data::morphemepiece_lookup
